@@ -462,3 +462,241 @@ class Model:
         user_id: str
         t: str
         event_id: str
+
+
+class EmojiID:
+    得意 = 4
+    流泪 = 5
+    睡 = 8
+    大哭 = 9
+    尴尬 = 10
+    调皮 = 12
+    微笑 = 14
+    酷 = 16
+    可爱 = 21
+    傲慢 = 23
+    饥饿 = 24
+    困 = 25
+    惊恐 = 26
+    流汗 = 27
+    憨笑 = 28
+    悠闲 = 29
+    奋斗 = 30
+    疑问 = 32
+    嘘 = 33
+    晕 = 34
+    敲打 = 38
+    再见 = 39
+    发抖 = 41
+    爱情 = 42
+    跳跳 = 43
+    拥抱 = 49
+    蛋糕 = 53
+    咖啡 = 60
+    玫瑰 = 63
+    爱心 = 66
+    太阳 = 74
+    月亮 = 75
+    赞 = 76
+    握手 = 78
+    胜利 = 79
+    飞吻 = 85
+    西瓜 = 89
+    冷汗 = 96
+    擦汗 = 97
+    抠鼻 = 98
+    鼓掌 = 99
+    糗大了 = 100
+    坏笑 = 101
+    左哼哼 = 102
+    右哼哼 = 103
+    哈欠 = 104
+    委屈 = 106
+    左亲亲 = 109
+    可怜 = 111
+    示爱 = 116
+    抱拳 = 118
+    拳头 = 120
+    爱你 = 122
+    NO = 123
+    OK = 124
+    转圈 = 125
+    挥手 = 129
+    喝彩 = 144
+    棒棒糖 = 147
+    茶 = 171
+    泪奔 = 173
+    无奈 = 174
+    卖萌 = 175
+    小纠结 = 176
+    doge = 179
+    惊喜 = 180
+    骚扰 = 181
+    笑哭 = 182
+    我最美 = 183
+    点赞 = 201
+    托脸 = 203
+    托腮 = 212
+    啵啵 = 214
+    蹭一蹭 = 219
+    抱抱 = 222
+    拍手 = 227
+    佛系 = 232
+    喷脸 = 240
+    甩头 = 243
+    加油抱抱 = 246
+    脑阔疼 = 262
+    捂脸 = 264
+    辣眼睛 = 265
+    哦哟 = 266
+    头秃 = 267
+    问号脸 = 268
+    暗中观察 = 269
+    emm = 270
+    吃瓜 = 271
+    呵呵哒 = 272
+    我酸了 = 273
+    汪汪 = 277
+    汗 = 278
+    无眼笑 = 281
+    敬礼 = 282
+    面无表情 = 284
+    摸鱼 = 285
+    哦 = 287
+    睁眼 = 289
+    敲开心 = 290
+    摸锦鲤 = 293
+    期待 = 294
+    拜谢 = 297
+    元宝 = 298
+    牛啊 = 299
+    右亲亲 = 305
+    牛气冲天 = 306
+    喵喵 = 307
+    仔细分析 = 314
+    加油 = 315
+    崇拜 = 318
+    比心 = 319
+    庆祝 = 320
+    拒绝 = 322
+    吃糖 = 324
+    生气 = 326
+
+
+class EmojiString:
+    得意 = "<emoji:4>"
+    流泪 = "<emoji:5>"
+    睡 = "<emoji:8>"
+    大哭 = "<emoji:9>"
+    尴尬 = "<emoji:10>"
+    调皮 = "<emoji:12>"
+    微笑 = "<emoji:14>"
+    酷 = "<emoji:16>"
+    可爱 = "<emoji:21>"
+    傲慢 = "<emoji:23>"
+    饥饿 = "<emoji:24>"
+    困 = "<emoji:25>"
+    惊恐 = "<emoji:26>"
+    流汗 = "<emoji:27>"
+    憨笑 = "<emoji:28>"
+    悠闲 = "<emoji:29>"
+    奋斗 = "<emoji:30>"
+    疑问 = "<emoji:32>"
+    嘘 = "<emoji:33>"
+    晕 = "<emoji:34>"
+    敲打 = "<emoji:38>"
+    再见 = "<emoji:39>"
+    发抖 = "<emoji:41>"
+    爱情 = "<emoji:42>"
+    跳跳 = "<emoji:43>"
+    拥抱 = "<emoji:49>"
+    蛋糕 = "<emoji:53>"
+    咖啡 = "<emoji:60>"
+    玫瑰 = "<emoji:63>"
+    爱心 = "<emoji:66>"
+    太阳 = "<emoji:74>"
+    月亮 = "<emoji:75>"
+    赞 = "<emoji:76>"
+    握手 = "<emoji:78>"
+    胜利 = "<emoji:79>"
+    飞吻 = "<emoji:85>"
+    西瓜 = "<emoji:89>"
+    冷汗 = "<emoji:96>"
+    擦汗 = "<emoji:97>"
+    抠鼻 = "<emoji:98>"
+    鼓掌 = "<emoji:99>"
+    糗大了 = "<emoji:100>"
+    坏笑 = "<emoji:101>"
+    左哼哼 = "<emoji:102>"
+    右哼哼 = "<emoji:103>"
+    哈欠 = "<emoji:104>"
+    委屈 = "<emoji:106>"
+    左亲亲 = "<emoji:109>"
+    可怜 = "<emoji:111>"
+    示爱 = "<emoji:116>"
+    抱拳 = "<emoji:118>"
+    拳头 = "<emoji:120>"
+    爱你 = "<emoji:122>"
+    NO = "<emoji:123>"
+    OK = "<emoji:124>"
+    转圈 = "<emoji:125>"
+    挥手 = "<emoji:129>"
+    喝彩 = "<emoji:144>"
+    棒棒糖 = "<emoji:147>"
+    茶 = "<emoji:171>"
+    泪奔 = "<emoji:173>"
+    无奈 = "<emoji:174>"
+    卖萌 = "<emoji:175>"
+    小纠结 = "<emoji:176>"
+    doge = "<emoji:179>"
+    惊喜 = "<emoji:180>"
+    骚扰 = "<emoji:181>"
+    笑哭 = "<emoji:182>"
+    我最美 = "<emoji:183>"
+    点赞 = "<emoji:201>"
+    托脸 = "<emoji:203>"
+    托腮 = "<emoji:212>"
+    啵啵 = "<emoji:214>"
+    蹭一蹭 = "<emoji:219>"
+    抱抱 = "<emoji:222>"
+    拍手 = "<emoji:227>"
+    佛系 = "<emoji:232>"
+    喷脸 = "<emoji:240>"
+    甩头 = "<emoji:243>"
+    加油抱抱 = "<emoji:246>"
+    脑阔疼 = "<emoji:262>"
+    捂脸 = "<emoji:264>"
+    辣眼睛 = "<emoji:265>"
+    哦哟 = "<emoji:266>"
+    头秃 = "<emoji:267>"
+    问号脸 = "<emoji:268>"
+    暗中观察 = "<emoji:269>"
+    emm = "<emoji:270>"
+    吃瓜 = "<emoji:271>"
+    呵呵哒 = "<emoji:272>"
+    我酸了 = "<emoji:273>"
+    汪汪 = "<emoji:277>"
+    汗 = "<emoji:278>"
+    无眼笑 = "<emoji:281>"
+    敬礼 = "<emoji:282>"
+    面无表情 = "<emoji:284>"
+    摸鱼 = "<emoji:285>"
+    哦 = "<emoji:287>"
+    睁眼 = "<emoji:289>"
+    敲开心 = "<emoji:290>"
+    摸锦鲤 = "<emoji:293>"
+    期待 = "<emoji:294>"
+    拜谢 = "<emoji:297>"
+    元宝 = "<emoji:298>"
+    牛啊 = "<emoji:299>"
+    右亲亲 = "<emoji:305>"
+    牛气冲天 = "<emoji:306>"
+    喵喵 = "<emoji:307>"
+    仔细分析 = "<emoji:314>"
+    加油 = "<emoji:315>"
+    崇拜 = "<emoji:318>"
+    比心 = "<emoji:319>"
+    庆祝 = "<emoji:320>"
+    拒绝 = "<emoji:322>"
+    吃糖 = "<emoji:324>"
+    生气 = "<emoji:326>"
